pub(super) async fn build_ws_backend<W>(
config: &ClientConfig,
codec: W,
) -> Result<(ClientBackend, WsConn<W>)>where
W: JsonRpcWsCodec,Expand description
Build the multiplexed backend by connecting over a WebSocket.
pub(super) async fn build_ws_backend<W>(
config: &ClientConfig,
codec: W,
) -> Result<(ClientBackend, WsConn<W>)>where
W: JsonRpcWsCodec,Build the multiplexed backend by connecting over a WebSocket.